//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[KokushiHoraHandPattern](index.md)/[agari](agari.md)

# agari

[common]\
open override val [agari](agari.md): [Tile](../../mahjongutils.models/-tile/index.md)

和牌张
